.. rst-class:: detail

FutureResult
=======================

.. currentmodule:: compas_rrc

.. autoclass:: FutureResult

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~FutureResult.__init__
        ~FutureResult.result
    
    